@@ -56,9 +56,9 @@ cie <- function(vismodeldata, space = c("XYZ", "LAB", "LCh")) {
 
   dat <- vismodeldata
 
-  X <- dat[,names(dat) %in% c('X', 'cie2_X', 'cie10_X')]
-  Y <- dat[,names(dat) %in% c('Y', 'cie2_Y', 'cie10_Y')]
-  Z <- dat[,names(dat) %in% c('Z', 'cie2_Z', 'cie10_Z')]
+  X <- dat[, names(dat) %in% c("X", "cie2_X", "cie10_X")]
+  Y <- dat[, names(dat) %in% c("Y", "cie2_Y", "cie10_Y")]
+  Z <- dat[, names(dat) %in% c("Z", "cie2_Z", "cie10_Z")]
 
   # Coordinates in the chosen CIE space
   if (space == "XYZ") {
@@ -74,14 +74,15 @@ cie <- function(vismodeldata, space = c("XYZ", "LAB", "LCh")) {
     Xn <- sum(S[, 1] * illum)
     Yn <- sum(S[, 2] * illum)
     Zn <- sum(S[, 3] * illum)
+    # Xn <- Yn <- Zn <- 65535
     # Xn = 94.811
     # Yn = 100
     # Zn = 107.304
 
     # LAB calculator
     f <- function(x) {
-      if (isTRUE(x > (6 / 29) ^ 3)) {
-        x ^ (1 / 3)
+      if (isTRUE(x > (6 / 29)^3)) {
+        x^(1 / 3)
       } else {
         (841 / 108) * x + (4 / 29)
       }
@@ -94,8 +95,13 @@ cie <- function(vismodeldata, space = c("XYZ", "LAB", "LCh")) {
     a <- 500 * (f(X / Xn) - f(Y / Yn))
     b <- 200 * (f(Y / Yn) - f(Z / Zn))
 
+    # Rescale
+    L <- L * 10
+    a <- a * 10
+    b <- b * 10
+
     # LCh calculator
-    C <- sqrt(a ^ 2 + b ^ 2)
+    C <- sqrt(a^2 + b^2)
     h <- atan2(b, a) * (180 / pi)
     h[h < 0] <- h[h < 0] + 360
   }
@@ -129,4 +135,4 @@ cie <- function(vismodeldata, space = c("XYZ", "LAB", "LCh")) {
   attr(res, "data.background") <- attr(vismodeldata, "data.background")
 
   res
-}
\ No newline at end of file
+}
