@@ -1,8 +1,8 @@
 #' Converts between irradiance and photon (quantum) flux
 #'
-#' Some spectrometers will give illuminant values in units of irradiance 
-#' (uWatt * cm^-2), but physiological models require illuminants in units of 
-#' photon (quantum) flux (umol * s^-1 * m^-2). The functions \code{irrad2flux} 
+#' Some spectrometers will give illuminant values in units of irradiance
+#' (uWatt * cm^-2), but physiological models require illuminants in units of
+#' photon (quantum) flux (umol * s^-1 * m^-2). The functions \code{irrad2flux}
 #' and \code{flux2irrad} allows for easy conversion of \code{rspec} objects
 #' between these units.
 #'
@@ -12,16 +12,16 @@
 #'
 #' @author Rafael Maia \email{rm72@@zips.uakron.edu}
 
-irrad2flux <- function(rspecdata){
-
-  if(!is.rspec(rspecdata))
+irrad2flux <- function(rspecdata) {
+  if (!is.rspec(rspecdata)) {
     stop("not an object of class rspec")
+  }
 
   nam <- names(rspecdata)
   wl <- rspecdata[, nam == "wl"]
 
-  K <- 0.01/(6.626*2.998*6.02308)
-  
+  K <- 0.01 / (6.626 * 2.998 * 6.02308)
+
   rspecdata[, nam != "wl"] <- rspecdata[, nam != "wl"] * wl * K
 
   return(rspecdata)
@@ -30,17 +30,17 @@ irrad2flux <- function(rspecdata){
 
 #' @rdname irrad2flux
 
-flux2irrad <- function(rspecdata){
-
-  if(!is.rspec(rspecdata))
+flux2irrad <- function(rspecdata) {
+  if (!is.rspec(rspecdata)) {
     stop("not an object of class rspec")
+  }
 
   nam <- names(rspecdata)
   wl <- rspecdata[, nam == "wl"]
 
-  K <- 0.01/(6.626*2.998*6.02308)
-  
-  rspecdata[, nam!="wl"] <- rspecdata[, nam != "wl"] / (wl * K)
-  
+  K <- 0.01 / (6.626 * 2.998 * 6.02308)
+
+  rspecdata[, nam != "wl"] <- rspecdata[, nam != "wl"] / (wl * K)
+
   rspecdata
 }
