@@ -1,13 +1,13 @@
 library(pavo)
-context('processing')
+context("processing")
 
-test_that('Conversion to rspec', {
+test_that("Conversion to rspec", {
   fakedat <- data.frame(wl = seq(200, 800, 0.5), refl1 = rnorm(1201), refl2 = rnorm(1201))
-  
+
   expect_equal(dim(as.rspec(fakedat, lim = c(300, 700), interp = FALSE)), c(801, 3))
   expect_equal(dim(as.rspec(fakedat, lim = c(200, 800), interp = FALSE)), c(1201, 3))
   expect_equal(dim(as.rspec(fakedat, lim = c(300, 700), interp = TRUE)), c(401, 3))
-  expect_equal(as.data.frame(as.rspec(fakedat, lim = c(300, 700))['wl']), data.frame(wl = as.numeric(c(300:700))))
+  expect_equal(as.data.frame(as.rspec(fakedat, lim = c(300, 700))["wl"]), data.frame(wl = as.numeric(c(300:700))))
 
   # Matrix and df input should have the same output
   expect_equal(as.rspec(fakedat), as.rspec(as.matrix(fakedat)))
@@ -21,16 +21,14 @@ test_that('Conversion to rspec', {
 
   expect_warning(as.rspec(fakedat[, -1], lim = c(300, 700)), "user-specified range")
   expect_warning(as.rspec(fakedat[, -1]), "arbitrary index")
-  
+
   expect_error(as.rspec(fakedat, lim = c(300.1, 700), interp = FALSE), "limits")
   expect_error(as.rspec(fakedat, lim = c(300, 699.1), interp = FALSE), "limits")
-  
 })
 
-test_that('Spectra pre-processing', {
-  
+test_that("Spectra pre-processing", {
   data(sicalis)
-  
+
   expect_equal(dim(procspec(sicalis, opt = "bin", bins = 24)), c(24, 22))
   expect_equal(dim(procspec(sicalis, opt = "bin", bins = 33)), c(33, 22))
 })
